# Tutorials

Step-by-step guides for common phaser analyses.

## Getting Started

- [Quick Start](../quickstart.md) - Basic usage overview

## Analysis Tutorials

### Haplotype Analysis

- [Haplotype Proportion Estimation](haplotype_proportion.md)
  - Finding diagnostic markers
  - Window-based proportion estimation
  - HMM-based haplotype inference
  - Interpreting results

### Assembly Analysis

- [Assembly Painting](assembly_painting.md)
  - Mapping markers to contigs
  - Assigning contigs to haplotypes
  - Detecting chimeric contigs
  - Visualizing results

### Polyploid Analysis

- [Subgenome Deconvolution](subgenome_analysis.md)
  - Synteny-based assignment
  - Ortholog-based assignment
  - Evidence integration
  - Fractionation analysis

### Expression Analysis

- [Homeolog Expression Bias](expression_bias.md)
  - Loading expression data
  - Extracting homeolog expression
  - Calculating bias statistics
  - Condition-specific analysis
  - Testing subgenome dominance

## Example Workflows

Complete workflows with example data:

1. **Basic Proportion Analysis** - Estimate founder contributions in RILs
2. **Assembly Painting** - Paint a new assembly by haplotype
3. **Subgenome Analysis** - Full maize subgenome deconvolution
4. **Expression Bias** - Analyze drought-responsive homeolog bias

## Tips and Best Practices

- Start with a subset of data for testing
- Use appropriate quality filters for your data type
- Visualize intermediate results to catch issues early
- See [FAQ](../faq.md) for common questions
